/**
 * Copyright (c) 2007, 2020 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *    Artem Tikhomirov (Borland) - initial API and implementation
 *    Michael Golubev (Montages) - #386838 - migrate to Xtend2
 *   Aurelien Didier (ARTAL) - aurelien.didier51@gmail.com - Bug 569174
 */
package xpt.propsheet;

import com.google.common.base.Objects;
import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenNavigator;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenPropertySheet;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.Common;
import xpt.editor.VisualIDRegistry;
import xpt.navigator.NavigatorGroup;
import xpt.providers.ElementTypes;

@Singleton
@SuppressWarnings("all")
public class LabelProvider {
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  private ElementTypes xptElementTypes;
  
  @Inject
  private NavigatorGroup group;
  
  @Inject
  private VisualIDRegistry visualId;
  
  public CharSequence className(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    String _labelProviderClassName = it.getLabelProviderClassName();
    _builder.append(_labelProviderClassName);
    return _builder;
  }
  
  public CharSequence packageName(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    String _packageName = it.getPackageName();
    _builder.append(_packageName);
    return _builder;
  }
  
  public CharSequence qualifiedClassName(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(".");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    return _builder;
  }
  
  public CharSequence fullPath(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _qualifiedClassName = this.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    return _builder;
  }
  
  public CharSequence extendsList(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("extends org.eclipse.jface.viewers.BaseLabelProvider");
    return _builder;
  }
  
  public CharSequence implementsList(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("implements org.eclipse.jface.viewers.ILabelProvider");
    return _builder;
  }
  
  public CharSequence LabelProvider(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _copyright = this._common.copyright(it.getEditorGen());
    _builder.append(_copyright);
    _builder.newLineIfNotEmpty();
    _builder.append("package ");
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _generatedClassComment = this._common.generatedClassComment();
    _builder.append(_generatedClassComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    _builder.append(" ");
    CharSequence _extendsList = this.extendsList(it);
    _builder.append(_extendsList);
    _builder.append(" ");
    CharSequence _implementsList = this.implementsList(it);
    _builder.append(_implementsList);
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _textMethod = this.getTextMethod(it);
    _builder.append(_textMethod, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _imageMethod = this.getImageMethod(it);
    _builder.append(_imageMethod, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _unwrapMethods = this.unwrapMethods(it);
    _builder.append(_unwrapMethods, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _additions = this.additions(it);
    _builder.append(_additions, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence getTextMethod(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public String getText(Object element) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("element = unwrap(element);");
    _builder.newLine();
    {
      GenNavigator _navigator = it.getEditorGen().getNavigator();
      boolean _notEquals = (!Objects.equal(_navigator, null));
      if (_notEquals) {
        _builder.append("\t");
        _builder.append("if (element instanceof ");
        CharSequence _qualifiedClassName = this.group.qualifiedClassName(it.getEditorGen().getNavigator());
        _builder.append(_qualifiedClassName, "\t");
        _builder.append(") {");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("return ((");
        CharSequence _qualifiedClassName_1 = this.group.qualifiedClassName(it.getEditorGen().getNavigator());
        _builder.append(_qualifiedClassName_1, "\t\t");
        _builder.append(") element).getGroupName();");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
      }
    }
    _builder.append("\t");
    _builder.append("org.eclipse.gmf.runtime.emf.type.core.IElementType etype = getElementType(getView(element));");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return etype == null ? \"\" : etype.getDisplayName();");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence getImageMethod(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public org.eclipse.swt.graphics.Image getImage(Object element) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.eclipse.gmf.runtime.emf.type.core.IElementType etype = getElementType(getView(unwrap(element)));");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return etype == null ? null : ");
    CharSequence _qualifiedClassName = this.xptElementTypes.qualifiedClassName(it.getEditorGen().getDiagram());
    _builder.append(_qualifiedClassName, "\t");
    _builder.append(".getImage(etype);");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence unwrapMethods(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("private Object unwrap(Object element) {");
    _builder.newLine();
    _builder.append("if (element instanceof org.eclipse.jface.viewers.IStructuredSelection) {");
    _builder.newLine();
    _builder.append("return ((org.eclipse.jface.viewers.IStructuredSelection) element).getFirstElement();");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.append("return element;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_1 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_1);
    _builder.newLineIfNotEmpty();
    _builder.append("private org.eclipse.gmf.runtime.notation.View getView(Object element) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (element instanceof org.eclipse.gmf.runtime.notation.View) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return (org.eclipse.gmf.runtime.notation.View) element;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (element instanceof org.eclipse.core.runtime.IAdaptable) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return (org.eclipse.gmf.runtime.notation.View)");
    _builder.newLine();
    _builder.append("\t\t\t\t");
    _builder.append("((org.eclipse.core.runtime.IAdaptable) element).getAdapter(org.eclipse.gmf.runtime.notation.View.class);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return null;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    CharSequence _generatedMemberComment_2 = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment_2);
    _builder.newLineIfNotEmpty();
    _builder.append("private org.eclipse.gmf.runtime.emf.type.core.IElementType getElementType(org.eclipse.gmf.runtime.notation.View view) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("// For intermediate views climb up the containment hierarchy to find the one associated with an element type.");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("while (view != null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("int vid = ");
    CharSequence _qualifiedClassName = this.visualId.qualifiedClassName(it.getEditorGen().getDiagram());
    _builder.append(_qualifiedClassName, "\t\t");
    _builder.append(".getVisualID(view);");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("org.eclipse.gmf.runtime.emf.type.core.IElementType etype =");
    _builder.newLine();
    _builder.append("\t\t\t\t");
    CharSequence _qualifiedClassName_1 = this.xptElementTypes.qualifiedClassName(it.getEditorGen().getDiagram());
    _builder.append(_qualifiedClassName_1, "\t\t\t\t");
    _builder.append(".getElementType(vid);");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("if (etype != null) {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("return etype;");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("view = view.eContainer() instanceof org.eclipse.gmf.runtime.notation.View ?");
    _builder.newLine();
    _builder.append("\t\t\t\t");
    _builder.append("(org.eclipse.gmf.runtime.notation.View) view.eContainer() : null;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return null;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence additions(final GenPropertySheet it) {
    StringConcatenation _builder = new StringConcatenation();
    return _builder;
  }
}
