/**
 * Copyright (c) 2007, 2020 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *    Dmitry Stadnik (Borland) - initial API and implementation
 *    Artem Tikhomirov (Borland) - introduced GenAuditContext entity
 *                                 straightforward and simple #validate() implementation
 * 	  Michael Golubev (Montages) - #386838 - migrate to Xtend2
 */
package xpt.providers;

import com.google.common.base.Objects;
import com.google.common.collect.Iterables;
import com.google.inject.Inject;
import com.google.inject.Singleton;
import java.util.Arrays;
import metamodel.MetaModel;
import org.eclipse.emf.common.util.EList;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenAuditContext;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenAuditRoot;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenAuditRule;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenAuditable;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenAuditedMetricTarget;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenCommonBase;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenDiagram;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenDiagramElementTarget;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenDomainAttributeTarget;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenExpressionInterpreter;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenExpressionProviderBase;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenExpressionProviderContainer;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenJavaExpressionProvider;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenMetricRule;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.StringExtensions;
import plugin.Activator;
import xpt.Common;
import xpt.Common_qvto;
import xpt.GenAuditRoot_qvto;
import xpt.editor.VisualIDRegistry;
import xpt.expressions.getExpression;

@Singleton
@SuppressWarnings("all")
public class ValidationProvider {
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  @Extension
  private Common_qvto _common_qvto;
  
  @Inject
  @Extension
  private GenAuditRoot_qvto _genAuditRoot_qvto;
  
  @Inject
  private Activator xptActivator;
  
  @Inject
  private MetaModel xptMetaModel;
  
  @Inject
  private getExpression xptGetExpression;
  
  @Inject
  private MetricProvider xptMetricProvider;
  
  @Inject
  private VisualIDRegistry xptVisualIDRegistry;
  
  public CharSequence className(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    String _validationProviderClassName = it.getValidationProviderClassName();
    _builder.append(_validationProviderClassName);
    return _builder;
  }
  
  public CharSequence packageName(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    String _providersPackageName = it.getProvidersPackageName();
    _builder.append(_providersPackageName);
    return _builder;
  }
  
  public CharSequence qualifiedClassName(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(".");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    return _builder;
  }
  
  public CharSequence fullPath(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _qualifiedClassName = this.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    return _builder;
  }
  
  public CharSequence ValidationProvider(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _copyright = this._common.copyright(it.getEditorGen());
    _builder.append(_copyright);
    _builder.newLineIfNotEmpty();
    _builder.append("package ");
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _generatedClassComment = this._common.generatedClassComment();
    _builder.append(_generatedClassComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _constraintsActive = this.constraintsActive(it);
    _builder.append(_constraintsActive, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _shouldConstraintsBePrivate = this.shouldConstraintsBePrivate(it);
    _builder.append(_shouldConstraintsBePrivate, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _runWithActiveConstraints = this.runWithActiveConstraints(it);
    _builder.append(_runWithActiveConstraints, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _isInDefaultEditorContext = this.isInDefaultEditorContext(it);
    _builder.append(_isInDefaultEditorContext, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _selectors = this.selectors(it.getEditorGen().getAudits());
    _builder.append(_selectors, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _strategy_support = this.strategy_support(it);
    _builder.append(_strategy_support, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _constraintAdapters = this.constraintAdapters(it.getEditorGen().getAudits(), it);
    _builder.append(_constraintAdapters, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _additions = this.additions(it);
    _builder.append(_additions, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence constraintsActive(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("private static boolean constraintsActive = false;\t");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence shouldConstraintsBePrivate(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public static boolean shouldConstraintsBePrivate() {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return false;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence runWithActiveConstraints(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public static void runWithConstraints(org.eclipse.emf.transaction.TransactionalEditingDomain editingDomain, Runnable operation) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("final Runnable op = operation;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("Runnable task = new Runnable() {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("public void run() {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("try {");
    _builder.newLine();
    _builder.append("\t\t\t\t");
    _builder.append("constraintsActive = true;");
    _builder.newLine();
    _builder.append("\t\t\t\t");
    _builder.append("op.run();");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("} finally {");
    _builder.newLine();
    _builder.append("\t\t\t\t");
    _builder.append("constraintsActive = false;");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("};");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if(editingDomain != null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("try {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("editingDomain.runExclusive(task);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("} catch (Exception e) {");
    _builder.newLine();
    _builder.append("\t\t\t");
    CharSequence _qualifiedClassName = this.xptActivator.qualifiedClassName(it.getEditorGen().getPlugin());
    _builder.append(_qualifiedClassName, "\t\t\t");
    _builder.append(".getInstance().logError(\"Validation failed\", e); ");
    CharSequence _nonNLS = this._common.nonNLS(1);
    _builder.append(_nonNLS, "\t\t\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("task.run();");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence additions(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    return _builder;
  }
  
  public CharSequence selectors(final GenAuditRoot it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      EList<GenAuditContext> _clientContexts = it.getClientContexts();
      for(final GenAuditContext ctx : _clientContexts) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        _builder.append("public static class ");
        String _className = ctx.getClassName();
        _builder.append(_className);
        _builder.append(" implements org.eclipse.emf.validation.model.IClientSelector {");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_1 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_1, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("public boolean selects(Object object) {");
        _builder.newLine();
        {
          boolean _notEmpty = this._common_qvto.<GenDiagramElementTarget>notEmpty(Iterables.<GenDiagramElementTarget>filter(ctx.getRuleTargets(), GenDiagramElementTarget.class));
          if (_notEmpty) {
            _builder.append("\t");
            _builder.append("if (isInDefaultEditorContext(object) && object instanceof org.eclipse.gmf.runtime.notation.View) {");
            _builder.newLine();
            _builder.append("\t");
            _builder.append("\t");
            _builder.append("final int id = ");
            CharSequence _visualIDMethodCall = this.xptVisualIDRegistry.getVisualIDMethodCall(it.getEditorGen().getDiagram());
            _builder.append(_visualIDMethodCall, "\t\t");
            _builder.append("((org.eclipse.gmf.runtime.notation.View) object);");
            _builder.newLineIfNotEmpty();
            _builder.append("\t");
            _builder.append("\t");
            _builder.append("boolean result = false;");
            _builder.newLine();
            {
              Iterable<GenCommonBase> _targetDiagramElements = this._genAuditRoot_qvto.getTargetDiagramElements(ctx);
              for(final GenCommonBase e : _targetDiagramElements) {
                _builder.append("\t");
                _builder.append("result = result || id == ");
                CharSequence _visualID = VisualIDRegistry.visualID(e);
                _builder.append(_visualID, "\t");
                _builder.append(";");
                _builder.newLineIfNotEmpty();
              }
            }
            _builder.append("\t");
            _builder.append("\t");
            _builder.append("return result;");
            _builder.newLine();
            _builder.append("\t");
            _builder.append("}");
            _builder.newLine();
            _builder.append("\t");
            _builder.append("return false;");
            _builder.newLine();
          } else {
            _builder.append("\t");
            _builder.append("return isInDefaultEditorContext(object);");
            _builder.newLine();
          }
        }
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence isInDefaultEditorContext(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("static boolean isInDefaultEditorContext(Object object) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if(shouldConstraintsBePrivate() && !constraintsActive) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return false;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (object instanceof org.eclipse.gmf.runtime.notation.View) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return constraintsActive && ");
    CharSequence _modelID = VisualIDRegistry.modelID(it);
    _builder.append(_modelID, "\t\t");
    _builder.append(".equals(");
    CharSequence _modelIDMethodCall = this.xptVisualIDRegistry.getModelIDMethodCall(it);
    _builder.append(_modelIDMethodCall, "\t\t");
    _builder.append("((org.eclipse.gmf.runtime.notation.View) object));");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return true;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence strategy_support(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _hasDiagramElementTargetRule = this._genAuditRoot_qvto.hasDiagramElementTargetRule(it.getEditorGen().getAudits());
      if (_hasDiagramElementTargetRule) {
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        _builder.append("public static org.eclipse.emf.validation.service.ITraversalStrategy getNotationTraversalStrategy(");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("org.eclipse.emf.validation.service.IBatchValidator validator) {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("return new CtxSwitchStrategy(validator);");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
        _builder.newLine();
        CharSequence _generatedMemberComment_1 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_1);
        _builder.newLineIfNotEmpty();
        _builder.append("private static class CtxSwitchStrategy implements org.eclipse.emf.validation.service.ITraversalStrategy {");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_2 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_2, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("private org.eclipse.emf.validation.service.ITraversalStrategy defaultStrategy;");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_3 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_3, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("private int currentSemanticCtxId = -1;");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_4 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_4, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("private boolean ctxChanged = true;");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_5 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_5, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("private org.eclipse.emf.ecore.EObject currentTarget;");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_6 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_6, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("private org.eclipse.emf.ecore.EObject preFetchedNextTarget;");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_7 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_7, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("private final int[] contextSwitchingIdentifiers;");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_8 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_8, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("CtxSwitchStrategy(org.eclipse.emf.validation.service.IBatchValidator validator) {");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("this.defaultStrategy = validator.getDefaultTraversalStrategy();");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("this.contextSwitchingIdentifiers = new int[] {");
        _builder.newLine();
        _builder.append("\t\t\t");
        {
          Iterable<GenCommonBase> _allTargetDiagramElements = this._genAuditRoot_qvto.getAllTargetDiagramElements(it.getEditorGen().getAudits());
          boolean _hasElements = false;
          for(final GenCommonBase e : _allTargetDiagramElements) {
            if (!_hasElements) {
              _hasElements = true;
            } else {
              _builder.appendImmediate(",", "\t\t\t");
            }
            CharSequence _visualID = VisualIDRegistry.visualID(e);
            _builder.append(_visualID, "\t\t\t");
          }
        }
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("};");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("java.util.Arrays.sort(this.contextSwitchingIdentifiers);");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_9 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_9, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("public void elementValidated(org.eclipse.emf.ecore.EObject element,");
        _builder.newLine();
        _builder.append("\t\t\t");
        _builder.append("org.eclipse.core.runtime.IStatus status) {");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("defaultStrategy.elementValidated(element, status);");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_10 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_10, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("public boolean hasNext() {");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("return defaultStrategy.hasNext();");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_11 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_11, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("public boolean isClientContextChanged() {");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("if (preFetchedNextTarget == null) {");
        _builder.newLine();
        _builder.append("\t\t\t");
        _builder.append("preFetchedNextTarget = next();");
        _builder.newLine();
        _builder.append("\t\t\t");
        _builder.append("prepareNextClientContext(preFetchedNextTarget);");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("return ctxChanged;");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_12 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_12, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("public org.eclipse.emf.ecore.EObject next() {");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("org.eclipse.emf.ecore.EObject nextTarget = preFetchedNextTarget;");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("if (nextTarget == null) {");
        _builder.newLine();
        _builder.append("\t\t\t");
        _builder.append("nextTarget = defaultStrategy.next();");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("this.preFetchedNextTarget = null;");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("return this.currentTarget = nextTarget;");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_13 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_13, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("public void startTraversal(java.util.Collection traversalRoots,\torg.eclipse.core.runtime.IProgressMonitor monitor) {");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("defaultStrategy.startTraversal(traversalRoots, monitor);");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_14 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_14, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("private void prepareNextClientContext(org.eclipse.emf.ecore.EObject nextTarget) { ");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("if (nextTarget != null && currentTarget != null) {");
        _builder.newLine();
        _builder.append("\t\t\t");
        _builder.append("if (nextTarget instanceof org.eclipse.gmf.runtime.notation.View) {");
        _builder.newLine();
        _builder.append("\t\t\t\t");
        _builder.append("final int id = ");
        CharSequence _visualIDMethodCall = this.xptVisualIDRegistry.getVisualIDMethodCall(it.getEditorGen().getDiagram());
        _builder.append(_visualIDMethodCall, "\t\t\t\t");
        _builder.append("((org.eclipse.gmf.runtime.notation.View) nextTarget);");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t\t\t");
        _builder.append("int nextSemanticId = (id != -1 && java.util.Arrays.binarySearch(contextSwitchingIdentifiers, id) >= 0) ? id : -1;");
        _builder.newLine();
        _builder.append("\t\t\t\t");
        _builder.append("if ((currentSemanticCtxId != -1 && currentSemanticCtxId != nextSemanticId)");
        _builder.newLine();
        _builder.append("\t\t\t\t\t\t");
        _builder.append("|| (nextSemanticId != -1 && nextSemanticId != currentSemanticCtxId)) {");
        _builder.newLine();
        _builder.append("\t\t\t\t\t");
        _builder.append("this.ctxChanged = true;");
        _builder.newLine();
        _builder.append("\t\t\t\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("\t\t\t\t");
        _builder.append("currentSemanticCtxId = nextSemanticId;");
        _builder.newLine();
        _builder.append("\t\t\t");
        _builder.append("} else {");
        _builder.newLine();
        _builder.append("\t\t\t\t");
        _builder.append("// context of domain model");
        _builder.newLine();
        _builder.append("\t\t\t\t");
        _builder.append("this.ctxChanged = currentSemanticCtxId != -1;");
        _builder.newLine();
        _builder.append("\t\t\t\t");
        _builder.append("currentSemanticCtxId = -1;");
        _builder.newLine();
        _builder.append("\t\t\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("} else {");
        _builder.newLine();
        _builder.append("\t\t\t");
        _builder.append("this.ctxChanged = false;");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence constraintAdapters(final GenAuditRoot it, final GenDiagram diagram) {
    StringConcatenation _builder = new StringConcatenation();
    {
      GenExpressionProviderContainer _expressionProviders = diagram.getEditorGen().getExpressionProviders();
      boolean _notEquals = (!Objects.equal(_expressionProviders, null));
      if (_notEquals) {
        {
          final Function1<GenAuditRule, Boolean> _function = new Function1<GenAuditRule, Boolean>() {
            @Override
            public Boolean apply(final GenAuditRule a) {
              return Boolean.valueOf(a.isRequiresConstraintAdapter());
            }
          };
          Iterable<GenAuditRule> _filter = IterableExtensions.<GenAuditRule>filter(it.getRules(), _function);
          for(final GenAuditRule next : _filter) {
            CharSequence _constraintAdapter = this.constraintAdapter(next, diagram.getEditorGen().getExpressionProviders());
            _builder.append(_constraintAdapter);
            _builder.newLineIfNotEmpty();
          }
        }
        _builder.newLine();
        {
          final Function1<GenAuditRule, Boolean> _function_1 = new Function1<GenAuditRule, Boolean>() {
            @Override
            public Boolean apply(final GenAuditRule a) {
              return Boolean.valueOf(a.isRequiresConstraintAdapter());
            }
          };
          boolean _exists = IterableExtensions.<GenAuditRule>exists(it.getRules(), _function_1);
          if (_exists) {
            CharSequence _constraintAdapters_formatMethod = this.constraintAdapters_formatMethod(it);
            _builder.append(_constraintAdapters_formatMethod);
            _builder.newLineIfNotEmpty();
          }
        }
      }
    }
    return _builder;
  }
  
  public CharSequence constraintAdapter(final GenAuditRule it, final GenExpressionProviderContainer container) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if (((!Objects.equal(it.getTarget(), null)) && (!Objects.equal(it.getTarget().getContext(), null)))) {
        _builder.newLine();
        CharSequence _generatedMemberComment = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment);
        _builder.newLineIfNotEmpty();
        _builder.append("public static class ");
        String _constraintAdapterLocalClassName = it.getConstraintAdapterLocalClassName();
        _builder.append(_constraintAdapterLocalClassName);
        _builder.append(" extends org.eclipse.emf.validation.AbstractModelConstraint {");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.newLine();
        _builder.append("\t");
        CharSequence _generatedMemberComment_1 = this._common.generatedMemberComment();
        _builder.append(_generatedMemberComment_1, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("public org.eclipse.core.runtime.IStatus validate(org.eclipse.emf.validation.IValidationContext ctx) {");
        _builder.newLine();
        _builder.append("\t\t");
        CharSequence _constraintAdapter_initContext = this.constraintAdapter_initContext(it.getTarget(), it);
        _builder.append(_constraintAdapter_initContext, "\t\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        CharSequence _constraintAdapter_validateMethod = this.constraintAdapter_validateMethod(it.getRule().getProvider(), it);
        _builder.append(_constraintAdapter_validateMethod, "\t\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence constraintAdapters_formatMethod(final GenAuditRoot it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("static String formatElement(org.eclipse.emf.ecore.EObject object) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return org.eclipse.gmf.runtime.emf.core.util.EMFCoreUtil.getQualifiedName(object, true);");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  protected CharSequence _constraintAdapter_validateMethod(final GenExpressionProviderBase it, final GenAuditRule audit) {
    StringConcatenation _builder = new StringConcatenation();
    this._common_qvto.ERROR(("No idea how to evaluate an audit rule for " + it));
    return _builder;
  }
  
  protected CharSequence _constraintAdapter_validateMethod(final GenExpressionInterpreter it, final GenAuditRule audit) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("Object result = ");
    CharSequence _expression = this.xptGetExpression.getExpression(it, audit.getRule(), audit.getTarget().getContext());
    _builder.append(_expression);
    _builder.append(".evaluate(context);");
    _builder.newLineIfNotEmpty();
    _builder.append("if (result instanceof Boolean && ((Boolean) result).booleanValue()) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return org.eclipse.core.runtime.Status.OK_STATUS;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.append("return ctx.createFailureStatus(new Object[] { formatElement(ctx.getTarget()) });");
    _builder.newLine();
    return _builder;
  }
  
  protected CharSequence _constraintAdapter_validateMethod(final GenJavaExpressionProvider it, final GenAuditRule audit) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if ((it.isInjectExpressionBody() && (!StringExtensions.isNullOrEmpty(audit.getRule().getBody())))) {
        String _body = audit.getRule().getBody();
        _builder.append(_body);
        _builder.newLineIfNotEmpty();
      } else {
        if ((it.isThrowException() || (it.isInjectExpressionBody() && StringExtensions.isNullOrEmpty(audit.getRule().getBody())))) {
          _builder.append("// TODO: put validation code here");
          _builder.newLine();
          _builder.append("// Ensure that you remove @generated tag or use @generated NOT");
          _builder.newLine();
          _builder.append("//");
          _builder.newLine();
          _builder.append("// To construct approprate return value, use ctx.createSuccessStatus()");
          _builder.newLine();
          _builder.append("// or ctx.createFailureStatus(...)");
          _builder.newLine();
          _builder.append("throw new java.lang.UnsupportedOperationException(\"No user java implementation provided for #validate(IValidationContext) operation\"); ");
          CharSequence _nonNLS = this._common.nonNLS(1);
          _builder.append(_nonNLS);
          _builder.newLineIfNotEmpty();
        } else {
          _builder.append("return ctx.createFailureStatus(new Object[] { \"No user java implementation provided for #validate(IValidationContext) operation\" }); ");
          CharSequence _nonNLS_1 = this._common.nonNLS(1);
          _builder.append(_nonNLS_1);
          _builder.newLineIfNotEmpty();
        }
      }
    }
    return _builder;
  }
  
  /**
   * Contract: declare variable with the name 'context' of appropriate type
   */
  protected CharSequence _constraintAdapter_initContext(final GenAuditable it, final GenAuditRule audit) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _DeclareAndAssign = this.xptMetaModel.DeclareAndAssign(it.getContext(), "context", "ctx.getTarget()", false);
    _builder.append(_DeclareAndAssign);
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  protected CharSequence _constraintAdapter_initContext(final GenDomainAttributeTarget it, final GenAuditRule audit) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("final Object");
    _builder.append(" context = ctx.getTarget().eGet(");
    CharSequence _MetaFeature = this.xptMetaModel.MetaFeature(it.getAttribute());
    _builder.append(_MetaFeature);
    _builder.append(");");
    _builder.newLineIfNotEmpty();
    _builder.append("if (context == null) {");
    _builder.newLine();
    {
      boolean _isNullAsError = it.isNullAsError();
      if (_isNullAsError) {
        _builder.append("return ctx.createFailureStatus(new Object[] { formatElement(ctx.getTarget()) });");
        _builder.newLine();
      } else {
        _builder.append("return org.eclipse.core.runtime.Status.OK_STATUS;");
        _builder.newLine();
      }
    }
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  protected CharSequence _constraintAdapter_initContext(final GenAuditedMetricTarget it, final GenAuditRule audit) {
    StringConcatenation _builder = new StringConcatenation();
    {
      GenMetricRule _metric = it.getMetric();
      boolean _equals = Objects.equal(_metric, null);
      if (_equals) {
        _builder.append("final Number context = null /*FIXME: metric target was not correctly specified in the model*/;");
        _builder.newLine();
      } else {
        _builder.append("final Number context = ");
        CharSequence _invokeCalcMethod = this.xptMetricProvider.invokeCalcMethod(it.getMetric(), "ctx.getTarget()", false);
        _builder.append(_invokeCalcMethod);
        _builder.append(";");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public CharSequence constraintAdapter_validateMethod(final GenExpressionProviderBase it, final GenAuditRule audit) {
    if (it instanceof GenExpressionInterpreter) {
      return _constraintAdapter_validateMethod((GenExpressionInterpreter)it, audit);
    } else if (it instanceof GenJavaExpressionProvider) {
      return _constraintAdapter_validateMethod((GenJavaExpressionProvider)it, audit);
    } else if (it != null) {
      return _constraintAdapter_validateMethod(it, audit);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(it, audit).toString());
    }
  }
  
  public CharSequence constraintAdapter_initContext(final GenAuditable it, final GenAuditRule audit) {
    if (it instanceof GenAuditedMetricTarget) {
      return _constraintAdapter_initContext((GenAuditedMetricTarget)it, audit);
    } else if (it instanceof GenDomainAttributeTarget) {
      return _constraintAdapter_initContext((GenDomainAttributeTarget)it, audit);
    } else if (it != null) {
      return _constraintAdapter_initContext(it, audit);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(it, audit).toString());
    }
  }
}
